%bcond qt 1
%global vala 1

Summary: Utilities to generate, maintain and access the AppStream database
Name:    appstream
Version: 0.16.1
Release: 2%{?dist}
License: GPL-2.0-or-later AND LGPL-2.1-or-later
URL:     https://github.com/ximion/appstream
Source0: http://www.freedesktop.org/software/appstream/releases/AppStream-%{version}.tar.xz

BuildRequires: cmake, meson >= 0.62, gettext, gperf, gtk-doc, intltool, itstool, libstemmer-devel
BuildRequires: pkgconfig(cairo), pkgconfig(freetype2), pkgconfig(fontconfig)
BuildRequires: pkgconfig(gdk-pixbuf-2.0), pkgconfig(gio-2.0), pkgconfig(gobject-introspection-1.0)
BuildRequires: pkgconfig(libcurl), pkgconfig(librsvg-2.0), pkgconfig(libsystemd)
BuildRequires: pkgconfig(libxml-2.0),  pkgconfig(pango)
BuildRequires: pkgconfig(Qt5Core), qt5-linguist
BuildRequires: pkgconfig(xmlb), pkgconfig(yaml-0.1)
BuildRequires: sed, vala, xmlto

%description
AppStream makes it easy to access application information from the
AppStream database over a nice GObject-based interface.

%package devel
Summary:  Development files for %{name}
Requires: %{name} = %{version}-%{release}
Provides: appstream-vala = %{version}-%{release}
%description devel
%{summary}.

%package compose
Summary: Library for generating AppStream data
Requires: %{name} = %{version}-%{release}
%description compose
%{summary}.

%package compose-devel
Summary:  Development files for %{name}-compose library
Requires: %{name}-compose = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}
%description compose-devel
%{summary}.

%if %{with qt}
%package qt
Summary: Qt5 bindings for %{name}
Requires: %{name} = %{version}-%{release}
%description qt
%{summary}.

%package qt-devel
Summary:  Development files for %{name}-qt bindings
Requires: %{name}-qt%{?_isa} = %{version}-%{release}
Requires: pkgconfig(Qt5Core)
%description qt-devel
%{summary}.
%endif



%prep
%autosetup -n AppStream-%{version} -p1



%build
%{meson} \
 -Dcompose=true \
%if %{with qt}
 -Dqt=true \
%endif
 -Dvapi=%{?vala:true}%{!?vala:false}

%{meson_build}



%install
%{meson_install}

mkdir -p %{buildroot}/var/cache/app-info/{icons,gv,xmls}
touch %{buildroot}/var/cache/app-info/cache.watch

%find_lang appstream



%check
%{meson_test} ||:



%posttrans
%{_bindir}/appstreamcli refresh --force >& /dev/null ||:

%transfiletriggerin -- %{_datadir}/app-info/xmls
%{_bindir}/appstreamcli refresh --force >& /dev/null ||:

%transfiletriggerpostun -- %{_datadir}/app-info/xmls
%{_bindir}/appstreamcli refresh --force >& /dev/null ||:

%files -f appstream.lang
%license COPYING
%doc AUTHORS
%{_bindir}/appstreamcli
%config(noreplace) %{_sysconfdir}/appstream.conf
%dir %{_libdir}/girepository-1.0/
%{_libdir}/girepository-1.0/AppStream-1.0.typelib
%{_libdir}/libappstream.so.4*
%{_libdir}/libappstream.so.%{version}
%{_metainfodir}/org.freedesktop.appstream.cli.*.xml
%{_mandir}/man1/appstreamcli.1*
%{_datadir}/gettext/its/metainfo.*
%ghost /var/cache/app-info/cache.watch
%dir /var/cache/app-info/
%dir /var/cache/app-info/icons/
%dir /var/cache/app-info/gv/
%dir /var/cache/app-info/xmls/

%files devel
%{_includedir}/appstream/
%{_libdir}/libappstream.so
%{_libdir}/pkgconfig/appstream.pc
%dir %{_datadir}/gir-1.0/
%{_datadir}/gir-1.0/AppStream-1.0.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/appstream.deps
%{_datadir}/vala/vapi/appstream.vapi
%{_docdir}/appstream/html/
%exclude %{_datadir}/gtk-doc/html/appstream
%{_datadir}/installed-tests/appstream/metainfo-validate.test

%files compose
%{_libdir}/libappstream-compose.so.0*
%{_libdir}/girepository-1.0/AppStreamCompose-1.0.typelib
%{_libexecdir}/appstreamcli-compose
%{_metainfodir}/org.freedesktop.appstream.compose.metainfo.xml
%{_mandir}/man1/appstreamcli-compose.1*

%files compose-devel
%{_includedir}/appstream-compose/
%{_libdir}/libappstream-compose.so
%{_libdir}/pkgconfig/appstream-compose.pc
%dir %{_datadir}/gtk-doc/
%{_datadir}/gir-1.0/AppStreamCompose-1.0.gir
%dir %{_datadir}/gtk-doc/html/
%{_datadir}/gtk-doc/html/appstream-compose

%if %{with qt}
%files qt
%{_libdir}/libAppStreamQt.so.2*
%{_libdir}/libAppStreamQt.so.%{version}

%files qt-devel
%{_includedir}/AppStreamQt/
%{_libdir}/cmake/AppStreamQt/
%{_libdir}/libAppStreamQt.so
%endif


%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.16.1-2
- Rebuilt for loongarch release

* Sat Nov 25 2023 Chair <chairou@tencent.com> - 0.16.1-1
- Init

